@@ -41,7 +41,6 @@
 
 #include <eel/eel-debug.h>
 #include <eel/eel-gtk-extensions.h>
-#include <eel/eel-stock-dialogs.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk/gdkx.h>
 #include <gdk/gdkkeysyms.h>
@@ -872,50 +871,6 @@ nautilus_window_get_notebook (NautilusWindow *window)
     return window->priv->notebook;
 }
 
-/* Code should never force the window taller than this size.
- * (The user can still stretch the window taller if desired).
- */
-static guint
-get_max_forced_height (GdkScreen *screen)
-{
-    return (gdk_screen_get_height (screen) * 90) / 100;
-}
-
-/* Code should never force the window wider than this size.
- * (The user can still stretch the window wider if desired).
- */
-static guint
-get_max_forced_width (GdkScreen *screen)
-{
-    return (gdk_screen_get_width (screen) * 90) / 100;
-}
-
-/* This must be called when construction of NautilusWindow is finished,
- * since it depends on the type of the argument, which isn't decided at
- * construction time.
- */
-static void
-nautilus_window_set_initial_window_geometry (NautilusWindow *window)
-{
-    GdkScreen *screen;
-    guint max_width_for_screen, max_height_for_screen;
-    guint default_width, default_height;
-
-    screen = gtk_window_get_screen (GTK_WINDOW (window));
-
-    max_width_for_screen = get_max_forced_width (screen);
-    max_height_for_screen = get_max_forced_height (screen);
-
-    default_width = NAUTILUS_WINDOW_DEFAULT_WIDTH;
-    default_height = NAUTILUS_WINDOW_DEFAULT_HEIGHT;
-
-    gtk_window_set_default_size (GTK_WINDOW (window),
-                                 MIN (default_width,
-                                      max_width_for_screen),
-                                 MIN (default_height,
-                                      max_height_for_screen));
-}
-
 static gboolean
 save_sidebar_width_cb (gpointer user_data)
 {
@@ -1111,7 +1066,7 @@ places_sidebar_show_error_message_cb (GtkPlacesSidebar *sidebar,
 {
     NautilusWindow *window = NAUTILUS_WINDOW (user_data);
 
-    eel_show_error_dialog (primary, secondary, GTK_WINDOW (window));
+    show_error_dialog (primary, secondary, GTK_WINDOW (window));
 }
 
 static void
@@ -1883,7 +1838,6 @@ notebook_popup_menu_show (NautilusWindow *window,
 {
     GtkWidget *popup;
     GtkWidget *item;
-    int button, event_time;
     gboolean can_move_left, can_move_right;
     NautilusNotebook *notebook;
 
@@ -1931,24 +1885,8 @@ notebook_popup_menu_show (NautilusWindow *window,
 
     gtk_widget_show_all (popup);
 
-    if (event)
-    {
-        button = event->button;
-        event_time = event->time;
-    }
-    else
-    {
-        button = 0;
-        event_time = gtk_get_current_event_time ();
-    }
-
-    /* TODO is this correct? */
-    gtk_menu_attach_to_widget (GTK_MENU (popup),
-                               window->priv->notebook,
-                               NULL);
-
-    gtk_menu_popup (GTK_MENU (popup), NULL, NULL, NULL, NULL,
-                    button, event_time);
+    gtk_menu_popup_at_pointer (GTK_MENU (popup),
+                               (GdkEvent*) event);
 }
 
 /* emitted when the user clicks the "close" button of tabs */
@@ -2243,7 +2181,10 @@ nautilus_window_constructed (GObject *self)
 
     setup_toolbar (window);
 
-    nautilus_window_set_initial_window_geometry (window);
+    gtk_window_set_default_size (GTK_WINDOW (window),
+                                 NAUTILUS_WINDOW_DEFAULT_WIDTH,
+                                 NAUTILUS_WINDOW_DEFAULT_HEIGHT);
+
     setup_notebook (window);
     nautilus_window_set_up_sidebar (window);
 
@@ -2281,16 +2222,16 @@ nautilus_window_set_property (GObject      *object,
     switch (arg_id)
     {
         case PROP_DISABLE_CHROME:
-            {
-                window->priv->disable_chrome = g_value_get_boolean (value);
-            }
-            break;
+        {
+            window->priv->disable_chrome = g_value_get_boolean (value);
+        }
+        break;
 
         default:
-            {
-                G_OBJECT_WARN_INVALID_PROPERTY_ID (object, arg_id, pspec);
-            }
-            break;
+        {
+            G_OBJECT_WARN_INVALID_PROPERTY_ID (object, arg_id, pspec);
+        }
+        break;
     }
 }
 
@@ -2307,10 +2248,10 @@ nautilus_window_get_property (GObject    *object,
     switch (arg_id)
     {
         case PROP_DISABLE_CHROME:
-            {
-                g_value_set_boolean (value, window->priv->disable_chrome);
-            }
-            break;
+        {
+            g_value_set_boolean (value, window->priv->disable_chrome);
+        }
+        break;
     }
 }
 
@@ -2917,7 +2858,7 @@ nautilus_window_show_about_dialog (NautilusWindow *window)
                             * box to give credit to the translator(s).
                             */
                            "translator-credits", _("translator-credits"),
-                           "logo-icon-name", "system-file-manager",
+                           "logo-icon-name", "org.gnome.Nautilus",
                            NULL);
 }
 
